TncError

Enum TncError 

pub enum TncError {
    CommandFailed(String),
    TimedOut,
    IoError(Error),
}
Errors raised by the Tnc interface

Variants



CommandFailed(String)

TNC rejected a command with a FAULT message



TimedOut

Event timed out

This error indicates that an expected TNC event did not occur within the allotted time. The operation should probably be retried.



IoError(Error)

Socket connectivity problem

These errors are generally fatal and indicate serious, uncorrectable problems with the local ARDOP TNC connection.

  • io::ErrorKind::ConnectionReset: lost connection to TNC
  • io::ErrorKind::TimedOut: TNC did not respond to a command
  • io::ErrorKind::InvalidData: TNC sent a malformed or unsolicited command response